@@ -9,7 +9,7 @@ BASIC_API_PARAMS = {
     "host": "localhost",
     "username": "username@example.com",
     "password": "password",
-    "session": "00000000-1111-2222-3333-444444444444",
+    "session_id": "00000000-1111-2222-3333-444444444444",
 }
 
 api = BroadworksAPI(**BASIC_API_PARAMS)
